@@ -12,7 +12,9 @@ const {exec, spawnSync} = require('child_process');
 
 const spawnOptions = {encoding: 'utf8', env: process.env};
 const getPlatform = () => {
-  const platform = process.platform;
+  let platform = process.env.npm_config_platform;
+  if (platform) return platform;
+  platform = process.platform;
   if (platform !== 'linux') return platform;
   // detecting musl using algorithm from https://github.com/lovell/detect-libc under Apache License 2.0
   let result = spawnSync('getconf', ['GNU_LIBC_VERSION'], spawnOptions);
@@ -23,7 +25,10 @@ const getPlatform = () => {
     return platform + '-musl';
   return platform;
 };
-const platform = getPlatform();
+
+const platform = getPlatform(),
+  platformArch = process.env.npm_config_platform_arch || process.arch,
+  platformABI = process.env.npm_config_platform_abi || process.versions.modules;
 
 const isParamPresent = name => process.argv.indexOf('--' + name) > 0;
 
@@ -65,15 +70,14 @@ const getAssetUrlPrefix = () => {
   const url = process.env.npm_package_github || (process.env.npm_package_repository_type === 'git' && process.env.npm_package_repository_url),
     result = getRepo(url);
   if (!result) return null;
-  const host = mirrorHost || process.env[mirrorEnvVar] || 'https://github.com';
-  let assetUrl = host;
+  let assetUrl = mirrorHost || process.env[mirrorEnvVar] || 'https://github.com';
   if (!skipPath && !process.env[skipPathVar]) {
     assetUrl += `/${result[1]}/${result[2]}/releases/download`;
   }
   if (!skipVer && !process.env[skipVerVar]) {
     assetUrl += '/' + process.env.npm_package_version;
   }
-  assetUrl += `/${prefix}${platform}-${process.arch}-${process.versions.modules}${suffix}`;
+  assetUrl += `/${prefix}${platform}-${platformArch}-${platformABI}${suffix}`;
   return assetUrl;
 };
 
@@ -88,7 +92,7 @@ const isDev = async () => {
   return false;
 };
 
-const run = async (cmd, suppressOutput) =>
+const run = (cmd, suppressOutput) =>
   new Promise((resolve, reject) => {
     const p = exec(cmd);
     let closed = false;
@@ -106,6 +110,10 @@ const run = async (cmd, suppressOutput) =>
   });
 
 const isVerified = async () => {
+  if (process.env.npm_config_platform || process.env.npm_config_platform_arch || process.env.npm_config_platform_abi) {
+    console.log(`Fetched for the custom platform "${platform}-${platformArch}-${platformABI}" -- skipping the verification.`);
+    return true;
+  }
   try {
     if (process.env.npm_package_scripts_verify_build) {
       await run('npm run verify-build', true);
@@ -122,7 +130,7 @@ const isVerified = async () => {
   return true;
 };
 
-const get = async url =>
+const get = url =>
   new Promise((resolve, reject) => {
     const httpLib = isHttps.test(url) ? https : isHttp.test(url) ? http : null;
     if (!httpLib) {
@@ -132,7 +140,7 @@ const get = async url =>
     }
     let buffer = null;
     httpLib
-      .get(url, res => {
+      .get(url, {agent: false}, res => {
         if (res.statusCode >= 300 && res.statusCode < 400 && res.headers && res.headers.location) {
           get(res.headers.location).then(resolve, reject);
           return;
@@ -150,7 +158,8 @@ const get = async url =>
         });
         res.on('end', () => resolve(buffer));
       })
-      .on('error', e => reject(e));
+      .on('error', e => reject(e))
+      .end();
   });
 
 const write = async (name, data) => {
